from cpl_core.database.context import DatabaseContextABC
from cpl_query.extension import List
from gismo_data.abc.server_repository_abc import ServerRepositoryABC

from gismo_data.abc.user_repository_abc import UserRepositoryABC
from gismo_data.model.user import User


class UserRepositoryService(UserRepositoryABC):

    def __init__(self, db_context: DatabaseContextABC, servers: ServerRepositoryABC):
        self._context = db_context

        self._servers = servers

        UserRepositoryABC.__init__(self)

    def get_users(self) -> List[User]:
        users = List(User)
        results = self._context.select(User.get_select_all_string())
        for result in results:
            users.append(User(
                result[1],
                result[2],
                self._servers.get_server_by_id(result[3]),
                id=result[0]
            ))

        return users

    def get_user_by_id(self, id: int) -> User:
        result = self._context.select(User.get_select_by_id_string(id))
        return User(
            result[1],
            result[2],
            self._servers.get_server_by_id(result[3]),
            id=result[0]
        )

    def get_user_by_discord_id(self, discord_id: int) -> User:
        result = self._context.select(User.get_select_by_discord_id_string(discord_id))
        return User(
            result[1],
            result[2],
            self._servers.get_server_by_id(result[3]),
            id=result[0]
        )
